FablibManager
=============

.. automodule:: fabrictestbed_extensions.fablib.fablib
   :members:

.. autoclass:: fabrictestbed_extensions.fablib.fablib.FablibManager
   :members:
   :special-members: __init__, __str__
